==> haskell-hspec-expectations-0.8.2-193-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-expectations.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-expectations
version:              0.8.2
visibility:           public
id:                   hspec-expectations-0.8.2-6qi8cjonJ6NDcZGGp2xU9X
key:                  hspec-expectations-0.8.2-6qi8cjonJ6NDcZGGp2xU9X
license:              MIT
copyright:            (c) 2011-2015 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/hspec/hspec-expectations#readme
synopsis:             Catchy combinators for HUnit
description:
    Catchy combinators for HUnit: <https://github.com/hspec/hspec-expectations#readme>

category:             Testing
abi:                  dac4b951c078fd4fbe011faf4bba75e0
exposed:              True
exposed-modules:
    Test.Hspec.Expectations Test.Hspec.Expectations.Contrib

hidden-modules:
    Test.Hspec.Expectations.Matcher Paths_hspec_expectations

import-dirs:          /usr/lib/ghc-9.0.2/site-local/hspec-expectations-0.8.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/hspec-expectations-0.8.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/hspec-expectations-0.8.2
hs-libraries:         HShspec-expectations-0.8.2-6qi8cjonJ6NDcZGGp2xU9X
depends:
    HUnit-1.6.2.0-C1iPOmv2pdMIa65hP6dNHl base-4.15.1.0
    call-stack-0.4.0-AWZIvDgVjrSE2X5Lpd2ZLj

haddock-interfaces:
    /usr/share/doc/haskell-hspec-expectations/html/hspec-expectations.haddock

haddock-html:         /usr/share/doc/haskell-hspec-expectations/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-expectations-0.8.2-196-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-expectations.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-expectations
version:              0.8.2
visibility:           public
id:                   hspec-expectations-0.8.2-6ENonJrlXiL3eyiFXNFxH2
key:                  hspec-expectations-0.8.2-6ENonJrlXiL3eyiFXNFxH2
license:              MIT
copyright:            (c) 2011-2015 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/hspec/hspec-expectations#readme
synopsis:             Catchy combinators for HUnit
description:
    Catchy combinators for HUnit: <https://github.com/hspec/hspec-expectations#readme>

category:             Testing
abi:                  76ffd244775db9f79df2273d5f9f0cba
exposed:              True
exposed-modules:
    Test.Hspec.Expectations Test.Hspec.Expectations.Contrib

hidden-modules:
    Test.Hspec.Expectations.Matcher Paths_hspec_expectations

import-dirs:          /usr/lib/ghc-9.0.2/site-local/hspec-expectations-0.8.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/hspec-expectations-0.8.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/hspec-expectations-0.8.2
hs-libraries:         HShspec-expectations-0.8.2-6ENonJrlXiL3eyiFXNFxH2
depends:
    HUnit-1.6.2.0-KAwdAgbRzrx72Ur0Y1YkJC base-4.15.1.0
    call-stack-0.4.0-6JET1pROhIkC7Lt9wogpdC

haddock-interfaces:
    /usr/share/doc/haskell-hspec-expectations/html/hspec-expectations.haddock

haddock-html:         /usr/share/doc/haskell-hspec-expectations/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
